@@ -353,6 +353,8 @@ class workspace:
 
         # Ask after widget loaded
 
+        self.linenumbers.redraw() # TODO: move to generic redraw functions
+
         self.root.after(50, hello)
 
         # Check temporary file
@@ -1193,7 +1195,7 @@ class workspace:
     def killall(self, event=None):
         """ Stops all player objects """
         execute("_Clock.clear()", verbose=False)
-        print("Clearing the scheduling clock.")
+        print("Clock.clear()")
         return "break"
 
     # Zoom in: Ctrl+=
