@@ -23,7 +23,6 @@ from .ServerManager import *
 from .SCLang import SynthDefs, Env, SynthDef, CompiledSynthDef
 from .Root import Root
 from .Scale import Scale, Tuning
-from .Workspace import get_keywords
 
 # stdlib imports
 
@@ -213,6 +212,8 @@ FoxDot = _util()
 
 # Create a clock and define functions
 
+_ = None
+
 logging.basicConfig(level=logging.ERROR)
 when.set_namespace(FoxDotCode) # experimental
 
